@@ -2,7 +2,9 @@
 // pub mod mnemonic_key;
 mod private;
 mod public;
+mod signature;
 
 pub use private::PrivateKey;
 
 pub use public::PublicKey;
+pub use signature::Signature;
